import itertools
import math

def distance(p1, p2):
    """Вычисление евклидова расстояния между двумя точками."""
    return math.sqrt((p1[0] - p2[0])**2 + (p1[1] - p2[1])**2)

def solve_tsp(points):
    """Решение задачи коммивояжера полным перебором."""
    n = len(points)
    min_route_length = float('inf')
    
    # Перебираем все возможные перестановки точек (кроме первой, которая фиксируется)
    for perm in itertools.permutations(range(1, n)):
        # Начинаем и заканчиваем в первой точке
        route = (0,) + perm + (0,)
        route_length = sum(distance(points[route[i]], points[route[i+1]]) for i in range(len(route) - 1))
        
        # Обновляем минимальную длину маршрута
        min_route_length = min(min_route_length, route_length)
    
    return min_route_length

# Чтение входных данных
n = int(input())
points = [tuple(map(int, input().split())) for _ in range(n)]

# Вычисление и вывод результата
result = solve_tsp(points)
print(f"{result:.9f}")
